@@ -1,7 +1,6 @@
-diff -rwub makeself.orig/makeself.sh makeself/makeself.sh
---- makeself.sh	Wed Oct 20 20:15:41 2004
-+++ makeself.sh	Wed Oct 20 20:16:30 2004
-@@ -106,7 +106,7 @@
+--- makeself.sh.orig	2008-01-04 17:53:49.000000000 -0600
++++ makeself.sh	2010-08-14 21:17:27.000000000 -0500
+@@ -126,7 +126,7 @@
  APPEND=n
  COPY=none
  TAR_ARGS=cvf
